==> nrd-front-0.4.0.tgz: package/README.md <==
# Nrd-Front [![pipeline status](https://labs.nereide.fr/10031/nrd-front/badges/master/pipeline.svg)](https://labs.nereide.fr/10031/nrd-front/-/commits/master)

Ce paquet contient plusieurs composants Vuejs (stylés avec
[tailwind](https://tailwindcss.com)) utilisés dans différents projets Néréide.


## Usage

Pour utiliser les composants de `nrd-front` il faut enregistrer le plugin Vuejs
associé :

```js
import Vue from "vue";

import { NrdPlugin } from "nrd-front";

Vue.use(NrdPlugin);
```

Il est possible de personnaliser ce plugin (notamment les classes tailwind) :

```js
Vue.use(NrdPlugin, {
    twprefix: 'op-',
    colors: {
        primary: "pink-500",
        secondary: "green-500",
        textLight: "orange-400",
        default: "black",
        success: "green-500",
        info: "blue-500",
        error: "red-500",
        warning: "orange-500"
    }
  });
```

Les couleurs doivent correspondre à des parties de classes tailwind.
Soit celle par défaut (cf.
[doc](https://tailwindcss.com/docs/customizing-colors/#default-color-palette))
soit celle définie dans `tailwind.config.js`.

## Liste des composants

Tous les composants sont exportés à la racine du paquet, pour les utiliser on
peut donc faire :

```js
import { Calendar } from "nrd-front";
```

### Calendar

Un calendrier intéractif qui permet de sélectionner une date.

Props :

- `disableBefore` : permet de specifier une date avant laquelle on ne peut rien
 sélectionner

- `excludeDays` : permet d'indiquer les jours non ouvrés/fériés. Le paramètre attend une liste de dates au format 'yyyy/M/dd'

- `startDate` : permet d'indiquer la date d'ouverture du calendrier (seul le mois est récupéré)'

Events :

- `change` : émit lorsque l'utilisateur selectionne une date. Le payload
  contient un objet de la forme `{ selected: d }` avec `d` une instance de
  `Date`


### Loading

Trois points de couleur avec une animation.

Props :

- `color` : le nom d'une couleur prédéfine pour les trois points

  - `white`
  - `black`
  - `orange`
  - `blue`
  - `gray`
  - `grayLight`

- `customColor` : une couleur arbitraire (passé à la propriété css
  `background-color`)

## Écrire un nouveau composant

Pour écrire un nouveau composant (par exemple `Modal`) voici les étapes :

1. ajouter une story dans le dossier `stories` : `stories/Modal.stories.js`
   Pour le contenu voire une story existante
2. ajouter le composant en tant que tel dans `src/components` : `src/components/modal.vue`
3. ajouter l'export dans `src/index.ts`

## Tester le composant

Pour tester les composants et faciliter le développement, 
il est possible de lancer le storybook avec la commande suivante:

`npm run storybook`

### La directive `v-twclass`

Pour les classes css tailwind, il faut utiliser la directive `v-twclass`.
Cette directive permet d'ajouter un prefix automatiquement et de personnaliser
les couleurs (cf. [usage](#usage)).

## Déployer une nouvelle révision

Pour déployer une nouvelle version de la librairie, il faut changer de
version dans package.json, ajouter un tag correspondant dans le dépôt
git.

Ensuite il faut générer l'archive de la librairie via `npm pack` et le
copier sur : staticweb.nereide.priv:/var/www/lib/nrd-front/)

==> nrd-front-0.4.1.tgz: package/README.md <==
# Nrd-Front [![pipeline status](https://labs.nereide.fr/10031/nrd-front/badges/master/pipeline.svg)](https://labs.nereide.fr/10031/nrd-front/-/commits/master)

Ce paquet contient plusieurs composants Vuejs (stylés avec
[tailwind](https://tailwindcss.com)) utilisés dans différents projets Néréide.


## Usage

Pour utiliser les composants de `nrd-front` il faut enregistrer le plugin Vuejs
associé :

```js
import Vue from "vue";

import { NrdPlugin } from "nrd-front";

Vue.use(NrdPlugin);
```

Il est possible de personnaliser ce plugin (notamment les classes tailwind) :

```js
Vue.use(NrdPlugin, {
    twprefix: 'op-',
    colors: {
        primary: "pink-500",
        secondary: "green-500",
        textLight: "orange-400",
        default: "black",
        success: "green-500",
        info: "blue-500",
        error: "red-500",
        warning: "orange-500"
    }
  });
```

Les couleurs doivent correspondre à des parties de classes tailwind.
Soit celle par défaut (cf.
[doc](https://tailwindcss.com/docs/customizing-colors/#default-color-palette))
soit celle définie dans `tailwind.config.js`.

## Liste des composants

Tous les composants sont exportés à la racine du paquet, pour les utiliser on
peut donc faire :

```js
import { Calendar } from "nrd-front";
```

### Calendar

Un calendrier intéractif qui permet de sélectionner une date.

Props :

- `disableBefore` : permet de specifier une date avant laquelle on ne peut rien
 sélectionner

- `excludeDays` : permet d'indiquer les jours non ouvrés/fériés. Le paramètre attend une liste de dates au format 'yyyy/MM/dd'

- `startDate` : permet d'indiquer la date d'ouverture du calendrier (seul le mois est récupéré)'

Events :

- `change` : émit lorsque l'utilisateur selectionne une date. Le payload
  contient un objet de la forme `{ selected: d }` avec `d` une instance de
  `Date`


### Loading

Trois points de couleur avec une animation.

Props :

- `color` : le nom d'une couleur prédéfine pour les trois points

  - `white`
  - `black`
  - `orange`
  - `blue`
  - `gray`
  - `grayLight`

- `customColor` : une couleur arbitraire (passé à la propriété css
  `background-color`)

## Écrire un nouveau composant

Pour écrire un nouveau composant (par exemple `Modal`) voici les étapes :

1. ajouter une story dans le dossier `stories` : `stories/Modal.stories.js`
   Pour le contenu voire une story existante
2. ajouter le composant en tant que tel dans `src/components` : `src/components/modal.vue`
3. ajouter l'export dans `src/index.ts`

## Tester le composant

Pour tester les composants et faciliter le développement, 
il est possible de lancer le storybook avec la commande suivante:

`npm run storybook`

### La directive `v-twclass`

Pour les classes css tailwind, il faut utiliser la directive `v-twclass`.
Cette directive permet d'ajouter un prefix automatiquement et de personnaliser
les couleurs (cf. [usage](#usage)).

## Déployer une nouvelle révision

Pour déployer une nouvelle version de la librairie, il faut changer de
version dans package.json, ajouter un tag correspondant dans le dépôt
git.

Ensuite il faut recompiler le projet `npm run build` et générer l'archive de la librairie via `npm pack` et le
copier sur : staticweb.nereide.priv:/var/www/lib/nrd-front/ (cf wiki rebond nereide.priv)
